Struct Clock
pub struct Clock { /* private fields */ }Expand description
Clock management.
Implementations
impl Clock
impl Clock
pub const unsafe fn from_ptr(ptr: *mut ()) -> Clock
pub const fn as_ptr(&self) -> *mut ()
pub const fn tasks_hfclkstart(self) -> Reg<u32, W>
pub const fn tasks_hfclkstart(self) -> Reg<u32, W>
Start HFCLK128M/HFCLK64M source as selected in HFCLKSRC.
pub const fn tasks_hfclkstop(self) -> Reg<u32, W>
pub const fn tasks_hfclkstop(self) -> Reg<u32, W>
Stop HFCLK128M/HFCLK64M source.
pub const fn tasks_lfclkstart(self) -> Reg<u32, W>
pub const fn tasks_lfclkstart(self) -> Reg<u32, W>
Start LFCLK source as selected in LFCLKSRC.
pub const fn tasks_lfclkstop(self) -> Reg<u32, W>
pub const fn tasks_lfclkstop(self) -> Reg<u32, W>
Stop LFCLK source.
pub const fn subscribe_hfclkstart(self) -> Reg<Subscribe, RW>
pub const fn subscribe_hfclkstart(self) -> Reg<Subscribe, RW>
Subscribe configuration for task HFCLKSTART.
pub const fn subscribe_hfclkstop(self) -> Reg<Subscribe, RW>
pub const fn subscribe_hfclkstop(self) -> Reg<Subscribe, RW>
Subscribe configuration for task HFCLKSTOP.
pub const fn subscribe_lfclkstart(self) -> Reg<Subscribe, RW>
pub const fn subscribe_lfclkstart(self) -> Reg<Subscribe, RW>
Subscribe configuration for task LFCLKSTART.
pub const fn subscribe_lfclkstop(self) -> Reg<Subscribe, RW>
pub const fn subscribe_lfclkstop(self) -> Reg<Subscribe, RW>
Subscribe configuration for task LFCLKSTOP.
pub const fn subscribe_cal(self) -> Reg<Subscribe, RW>
pub const fn subscribe_cal(self) -> Reg<Subscribe, RW>
Subscribe configuration for task CAL.
pub const fn events_hfclkstarted(self) -> Reg<u32, RW>
pub const fn events_hfclkstarted(self) -> Reg<u32, RW>
HFCLK128M/HFCLK64M source started.
pub const fn events_lfclkstarted(self) -> Reg<u32, RW>
pub const fn events_lfclkstarted(self) -> Reg<u32, RW>
LFCLK source started.
pub const fn events_done(self) -> Reg<u32, RW>
pub const fn events_done(self) -> Reg<u32, RW>
Calibration of LFRC oscillator complete event.
pub const fn publish_hfclkstarted(self) -> Reg<Publish, RW>
pub const fn publish_hfclkstarted(self) -> Reg<Publish, RW>
Publish configuration for event HFCLKSTARTED.
pub const fn publish_lfclkstarted(self) -> Reg<Publish, RW>
pub const fn publish_lfclkstarted(self) -> Reg<Publish, RW>
Publish configuration for event LFCLKSTARTED.
pub const fn publish_done(self) -> Reg<Publish, RW>
pub const fn publish_done(self) -> Reg<Publish, RW>
Publish configuration for event DONE.
pub const fn hfclkrun(self) -> Reg<Hfclkrun, R>
pub const fn hfclkrun(self) -> Reg<Hfclkrun, R>
Status indicating that HFCLKSTART task has been triggered.
pub const fn hfclkstat(self) -> Reg<Hfclkstat, R>
pub const fn hfclkstat(self) -> Reg<Hfclkstat, R>
Status indicating which HFCLK128M/HFCLK64M source is running This register value in any CLOCK instance reflects status only due to configurations/actions in that CLOCK instance.
pub const fn lfclkrun(self) -> Reg<Lfclkrun, R>
pub const fn lfclkrun(self) -> Reg<Lfclkrun, R>
Status indicating that LFCLKSTART task has been triggered.
pub const fn lfclkstat(self) -> Reg<Lfclkstat, R>
pub const fn lfclkstat(self) -> Reg<Lfclkstat, R>
Status indicating which LFCLK source is running This register value in any CLOCK instance reflects status only due to configurations/actions in that CLOCK instance.
pub const fn lfclksrccopy(self) -> Reg<Lfclksrccopy, R>
pub const fn lfclksrccopy(self) -> Reg<Lfclksrccopy, R>
Copy of LFCLKSRC register, set when LFCLKSTART task was triggered.
pub const fn hfclkalwaysrun(self) -> Reg<Hfclkalwaysrun, RW>
pub const fn hfclkalwaysrun(self) -> Reg<Hfclkalwaysrun, RW>
Automatic or manual control of HFCLK128M/HFCLK64M.
pub const fn lfclkalwaysrun(self) -> Reg<Lfclkalwaysrun, RW>
pub const fn lfclkalwaysrun(self) -> Reg<Lfclkalwaysrun, RW>
Automatic or manual control of LFCLK.